import React from 'react';
import PropTypes from 'prop-types';
import NativeCharts from 'native-echarts';

// TODO: integrate styles
// import getStyles from './BarChart.styles';

/**
 * The bar chart shows different data through the height of a bar, which is used in rectangular coordinate with at least 1 category axis.
 */
const BarChart = (props) => {
    const {
        animation,
        // contextStyles,
        height,
        horizontal,
        legend,
        legendOrientation,
        seriesData,
        seriesName,
        titleText,
        xAxisLabels,
    } = props;

    // TODO: integrate styles
    // const styles = getStyles(contextStyles);

    // Handle horizontal/vertical displays
    const xAxis = horizontal ? {} : { data: xAxisLabels };
    const yAxis = horizontal ? { data: xAxisLabels } : {};

    // If we're displaying a legend, ensure we have something to display/link to
    const legendData = legend && seriesName ? [ seriesName ] : null;

    // Build bar chart options
    const option = {
        animation,
        title: {
            text: titleText,
        },
        legend: {
            orient: legendOrientation,
            data: legendData,
        },
        xAxis,
        yAxis,
        series: [
            {
                name: seriesName,
                type: 'bar',
                data: seriesData,
            },
        ],
    };

    return (
        <NativeCharts
            option={ option }
            height={ height } />
    );
};

BarChart.propTypes = {
    /** Enables/disables chart animations */
    animation: PropTypes.bool,

    /** Styles for the component */
    // contextStyles: {},

    /** The height of the chart */
    height: PropTypes.number,

    /** Displays the bars horizontally from left to right */
    horizontal: PropTypes.bool,

    /** Displays a legend with the `seriesName` as the legend text for the represented bars */
    legend: PropTypes.bool,

    /** Layout of the legend items */
    legendOrientation: PropTypes.oneOf([
        'horizontal',
        'vertical',
    ]),

    /** The data points to display for each bar */
    seriesData: PropTypes.arrayOf(PropTypes.number),

    /** Used with the `legend` prop to map `seriesData` to the legend */
    seriesName: PropTypes.string,

    /** Title text for the chart */
    titleText: PropTypes.string,

    /** Text to display for each bar along its base X axis */
    xAxisLabels: PropTypes.arrayOf(PropTypes.string),
};

BarChart.defaultProps = {
    animation: true,
    height: 300,
    legendOrientation: 'horizontal',
};

export default BarChart;
