import React from 'react';
import PropTypes from 'prop-types';
import NativeCharts from 'native-echarts';

/**
 * The pie chart is mainly used for showing proportion of different categories.
 * Each arc length represents the proportion of data quantity.
 */
const PieChart = (props) => {
    const {
        height,
    } = props;

    const option = {
        title : {
            text: '某站点用户访问来源',
            subtext: '纯属虚构',
            x:'center',
        },
        legend: {
            orient: 'vertical',
            left: 'left',
            data: [ '直接访问','邮件营销','联盟广告','视频广告','搜索引擎' ],
        },
        series: [
            {
                name: '访问来源',
                type: 'pie',
                radius: '55%',
                center: [ '50%', '60%' ],
                data:[
                    { value:335, name:'直接访问' },
                    { value:310, name:'邮件营销' },
                    { value:234, name:'联盟广告' },
                    { value:135, name:'视频广告' },
                    { value:1548, name:'搜索引擎' },
                ],
                itemStyle: {
                    emphasis: {
                        shadowBlur: 10,
                        shadowOffsetX: 0,
                        shadowColor: 'rgba(0, 0, 0, 0.5)',
                    },
                },
            },
        ],
    };

    return (
        <NativeCharts
            option={ option }
            height={ height } />
    );
};

PieChart.propTypes = {
    height: PropTypes.number,
    isHorizontal: PropTypes.bool,
    seriesData: PropTypes.arrayOf(PropTypes.number),
    seriesName: PropTypes.string,
    titleText: PropTypes.string,
    xAxisLabels: PropTypes.arrayOf(PropTypes.string),
};

PieChart.defaultProps = {};

export default PieChart;
