import React from 'react';
import PropTypes from "prop-types";
import MuiButton from '@material-ui/core/Button';
import { MuiThemeProvider, createMuiTheme } from '@material-ui/core/styles';

import getStyles from './Button.styles';

/**
 * Button component description
 * @see https://material-ui.com/demos/buttons/
 * @see https://material-ui.com/api/button/
 * @see https://material-ui.com/api/button-base/
 */
const Button = (props) => {

    const {
        contextStyles,
        ...rest
    } = props;

    const styles = getStyles(contextStyles);

    const theme = createMuiTheme({
        typography: {
            // https://material-ui.com/style/typography/#migration-to-typography-v2
            useNextVariants: true,
        },
        overrides: {
            MuiButton: { // Name of the component ⚛️ / style sheet
                root: { // Name of the rule
                    ...styles.container,
                },
                label: {
                    ...styles.label,
                },
            },
        },
    });

    return (
        <MuiThemeProvider theme={ theme }>
            <MuiButton
                style={ styles }
                { ...rest } />
        </MuiThemeProvider>
    );
};

Button.propTypes = {

    /** Styles for this component */
    contextStyles: PropTypes.shape({

        /** Styling for the main button container */
        container: PropTypes.object,

        /** Styles for the button text */
        text: PropTypes.object,
    }),

    /** Text displayed inside the button */
    children: PropTypes.string,

    /** Disable the button */
    disabled: PropTypes.bool,

    /**
     * Called when the button is pressed
     * @param {SyntheticEvent} event - The native click event
     */
    onClick: PropTypes.func,
};

Button.defaultProps = {
    contextStyles: {},
    variant: 'contained',
};

export default Button;
